# The Clipper C++ crystallographic library already uses the name "clipper".
# The developer is fine with the choosen name.

# API monitoring
# http://upstream-tracker.org/versions/clipper.html

%{?mingw_package_header}

%global mingw_pkg_name polyclipping

Name:           mingw-%{mingw_pkg_name}
Version:        5.1.2
Release:        2%{?dist}
Summary:        MinGW Windows Polygon clipping library

Group:          System Environment/Libraries
License:        Boost
URL:            http://sourceforge.net/projects/polyclipping
Source0:        http://downloads.sourceforge.net/%{mingw_pkg_name}/clipper_ver%{version}.zip
# Add __declspec annotations; make cmake install the import lib as well
# http://sourceforge.net/p/polyclipping/bugs/62/
Patch0:         polyclipping.patch

BuildRequires:  mingw32-filesystem
BuildRequires:  mingw64-filesystem
BuildRequires:  mingw32-gcc-c++
BuildRequires:  mingw64-gcc-c++
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildArch:      noarch

%description
This package contains the MinGW windows port of the clipper polygon
clipping library.

This library primarily performs the boolean clipping operations -
intersection, union, difference & xor - on 2D polygons. It also performs
polygon offsetting. The library handles complex (self-intersecting) polygons,
polygons with holes and polygons with overlapping co-linear edges.
Input polygons for clipping can use EvenOdd, NonZero, Positive and Negative
filling modes. The clipping code is based on the Vatti clipping algorithm,
and outperforms other clipping libraries.

# Mingw32
%package -n mingw32-%{mingw_pkg_name}
Summary:                MinGW Windows Polygon clipping library for the win32 target

%description -n mingw32-%{mingw_pkg_name}
This package contains the MinGW win32 port of the clipper polygon
clipping library.

This library primarily performs the boolean clipping operations -
intersection, union, difference & xor - on 2D polygons. It also performs
polygon offsetting. The library handles complex (self-intersecting) polygons,
polygons with holes and polygons with overlapping co-linear edges.
Input polygons for clipping can use EvenOdd, NonZero, Positive and Negative
filling modes. The clipping code is based on the Vatti clipping algorithm,
and outperforms other clipping libraries.

# Mingw64
%package -n mingw64-%{mingw_pkg_name}
Summary:                MinGW Windows Polygon clipping library for the win64 target

%description -n mingw64-%{mingw_pkg_name}
This package contains the MinGW win64 port of the clipper polygon
clipping library.

This library primarily performs the boolean clipping operations -
intersection, union, difference & xor - on 2D polygons. It also performs
polygon offsetting. The library handles complex (self-intersecting) polygons,
polygons with holes and polygons with overlapping co-linear edges.
Input polygons for clipping can use EvenOdd, NonZero, Positive and Negative
filling modes. The clipping code is based on the Vatti clipping algorithm,
and outperforms other clipping libraries.

%{?mingw_debug_package}

%prep
%setup -qc

# Delete binaries
find . \( -name "*.exe" -o -name "*.dll" \) -delete

# Correct line ends and encodings
find . -type f -exec dos2unix -k {} \;

for filename in perl/perl_readme.txt README; do
  iconv -f iso8859-1 -t utf-8 "${filename}" > "${filename}".conv && \
    touch -r "${filename}" "${filename}".conv && \
    mv "${filename}".conv "${filename}"
done

%patch0 -p0 -b .mingw


%build
pushd cpp
  %mingw_cmake
  %mingw_make %{?_smp_mflags}
popd


%install
pushd cpp
  %mingw_make install DESTDIR=%{buildroot}
popd

%files -n mingw32-%{mingw_pkg_name}
%doc License.txt README
%{mingw32_includedir}/*
%{mingw32_libdir}/libpolyclipping.dll.a
%{mingw32_bindir}/libpolyclipping.dll

%files -n mingw64-%{mingw_pkg_name}
%doc License.txt README
%{mingw64_includedir}/*
%{mingw64_libdir}/libpolyclipping.dll.a
%{mingw64_bindir}/libpolyclipping.dll


%changelog
* Thu Mar  7 2013 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.1.2-2
- export std::vector specializations from DLL as well

* Sun Jan 27 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 5.0.3-4
- Rebuild against mingw-gcc 4.8 (win64 uses SEH exceptions now)

* Sat Jan 19 2013 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.0.3-3
- fix summary to contain the correct architecture name

* Sat Jan 19 2013 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.0.3-2
- clarify this is the MinGW version in summary and description
- remove TODO comment

* Fri Jan 18 2013 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.0.3-1
- update to 5.0.3

* Thu Jan 10 2013 Thomas Sailer <t.sailer@alumni.ethz.ch> - 4.9.7-1
- created from native spec file
